var annotated_dup =
[
    [ "libcamera", "namespacelibcamera.html", [
      [ "utils", null, [
        [ "Duration", "classlibcamera_1_1utils_1_1Duration.html", "classlibcamera_1_1utils_1_1Duration" ],
        [ "ScopeExitActions", "classlibcamera_1_1utils_1_1ScopeExitActions.html", "classlibcamera_1_1utils_1_1ScopeExitActions" ]
      ] ],
      [ "ipa", "namespacelibcamera_1_1ipa.html", [
        [ "ipu3", null, [
          [ "algorithms", null, [
            [ "Af", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Af.html", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Af" ],
            [ "Agc", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Agc.html", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Agc" ],
            [ "Accumulator", "structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html", "structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator" ],
            [ "Awb", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb.html", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb" ],
            [ "BlackLevelCorrection", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1BlackLevelCorrection.html", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1BlackLevelCorrection" ],
            [ "ToneMapping", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1ToneMapping.html", "classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1ToneMapping" ]
          ] ],
          [ "IPASessionConfiguration", "structlibcamera_1_1ipa_1_1ipu3_1_1IPASessionConfiguration.html", "structlibcamera_1_1ipa_1_1ipu3_1_1IPASessionConfiguration" ],
          [ "IPAActiveState", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState" ],
          [ "IPAFrameContext", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAFrameContext.html", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAFrameContext" ],
          [ "IPAContext", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext.html", "structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext" ],
          [ "IPAIPU3", "classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html", "classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3" ]
        ] ],
        [ "AgcMeanLuminance", "classlibcamera_1_1ipa_1_1AgcMeanLuminance.html", "classlibcamera_1_1ipa_1_1AgcMeanLuminance" ],
        [ "Algorithm", "classlibcamera_1_1ipa_1_1Algorithm.html", "classlibcamera_1_1ipa_1_1Algorithm" ],
        [ "AlgorithmFactory", "classlibcamera_1_1ipa_1_1AlgorithmFactory.html", "classlibcamera_1_1ipa_1_1AlgorithmFactory" ],
        [ "AwbResult", "structlibcamera_1_1ipa_1_1AwbResult.html", "structlibcamera_1_1ipa_1_1AwbResult" ],
        [ "AwbStats", "structlibcamera_1_1ipa_1_1AwbStats.html", "structlibcamera_1_1ipa_1_1AwbStats" ],
        [ "AwbAlgorithm", "classlibcamera_1_1ipa_1_1AwbAlgorithm.html", "classlibcamera_1_1ipa_1_1AwbAlgorithm" ],
        [ "AwbBayes", "classlibcamera_1_1ipa_1_1AwbBayes.html", "classlibcamera_1_1ipa_1_1AwbBayes" ],
        [ "AwbGrey", "classlibcamera_1_1ipa_1_1AwbGrey.html", "classlibcamera_1_1ipa_1_1AwbGrey" ],
        [ "CameraSensorHelper", "classlibcamera_1_1ipa_1_1CameraSensorHelper.html", "classlibcamera_1_1ipa_1_1CameraSensorHelper" ],
        [ "CameraSensorHelperFactoryBase", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase.html", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase" ],
        [ "CameraSensorHelperFactory", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactory.html", "classlibcamera_1_1ipa_1_1CameraSensorHelperFactory" ],
        [ "ExposureModeHelper", "classlibcamera_1_1ipa_1_1ExposureModeHelper.html", "classlibcamera_1_1ipa_1_1ExposureModeHelper" ],
        [ "FCQueue", "classlibcamera_1_1ipa_1_1FCQueue.html", "classlibcamera_1_1ipa_1_1FCQueue" ],
        [ "FrameContext", "structlibcamera_1_1ipa_1_1FrameContext.html", null ],
        [ "Histogram", "classlibcamera_1_1ipa_1_1Histogram.html", "classlibcamera_1_1ipa_1_1Histogram" ],
        [ "Interpolator", "classlibcamera_1_1ipa_1_1Interpolator.html", "classlibcamera_1_1ipa_1_1Interpolator" ],
        [ "LscPolynomial", "classlibcamera_1_1ipa_1_1LscPolynomial.html", "classlibcamera_1_1ipa_1_1LscPolynomial" ],
        [ "Lux", "classlibcamera_1_1ipa_1_1Lux.html", "classlibcamera_1_1ipa_1_1Lux" ],
        [ "Module", "classlibcamera_1_1ipa_1_1Module.html", "classlibcamera_1_1ipa_1_1Module" ],
        [ "Pwl", "classlibcamera_1_1ipa_1_1Pwl.html", "classlibcamera_1_1ipa_1_1Pwl" ],
        [ "V4L2ParamsBlock", "classlibcamera_1_1ipa_1_1V4L2ParamsBlock.html", "classlibcamera_1_1ipa_1_1V4L2ParamsBlock" ],
        [ "V4L2Params", "classlibcamera_1_1ipa_1_1V4L2Params.html", "classlibcamera_1_1ipa_1_1V4L2Params" ]
      ] ],
      [ "Backtrace", "classlibcamera_1_1Backtrace.html", "classlibcamera_1_1Backtrace" ],
      [ "Extensible", "classlibcamera_1_1Extensible.html", "classlibcamera_1_1Extensible" ],
      [ "EventDispatcher", "classlibcamera_1_1EventDispatcher.html", "classlibcamera_1_1EventDispatcher" ],
      [ "EventDispatcherPoll", "classlibcamera_1_1EventDispatcherPoll.html", "classlibcamera_1_1EventDispatcherPoll" ],
      [ "EventNotifier", "classlibcamera_1_1EventNotifier.html", "classlibcamera_1_1EventNotifier" ],
      [ "File", "classlibcamera_1_1File.html", "classlibcamera_1_1File" ],
      [ "Flags", "classlibcamera_1_1Flags.html", "classlibcamera_1_1Flags" ],
      [ "LogCategory", "classlibcamera_1_1LogCategory.html", "classlibcamera_1_1LogCategory" ],
      [ "LogMessage", "classlibcamera_1_1LogMessage.html", "classlibcamera_1_1LogMessage" ],
      [ "Loggable", "classlibcamera_1_1Loggable.html", "classlibcamera_1_1Loggable" ],
      [ "MemFd", "classlibcamera_1_1MemFd.html", "classlibcamera_1_1MemFd" ],
      [ "Message", "classlibcamera_1_1Message.html", "classlibcamera_1_1Message" ],
      [ "InvokeMessage", "classlibcamera_1_1InvokeMessage.html", "classlibcamera_1_1InvokeMessage" ],
      [ "Mutex", "classlibcamera_1_1Mutex.html", null ],
      [ "MutexLocker", "classlibcamera_1_1MutexLocker.html", null ],
      [ "ConditionVariable", "classlibcamera_1_1ConditionVariable.html", null ],
      [ "Signal", "classlibcamera_1_1Signal.html", "classlibcamera_1_1Signal" ],
      [ "Object", "classlibcamera_1_1Object.html", "classlibcamera_1_1Object" ],
      [ "Semaphore", "classlibcamera_1_1Semaphore.html", "classlibcamera_1_1Semaphore" ],
      [ "SharedFD", "classlibcamera_1_1SharedFD.html", "classlibcamera_1_1SharedFD" ],
      [ "Thread", "classlibcamera_1_1Thread.html", "classlibcamera_1_1Thread" ],
      [ "Timer", "classlibcamera_1_1Timer.html", "classlibcamera_1_1Timer" ],
      [ "UniqueFD", "classlibcamera_1_1UniqueFD.html", "classlibcamera_1_1UniqueFD" ],
      [ "SensorConfiguration", "classlibcamera_1_1SensorConfiguration.html", "classlibcamera_1_1SensorConfiguration" ],
      [ "CameraConfiguration", "classlibcamera_1_1CameraConfiguration.html", "classlibcamera_1_1CameraConfiguration" ],
      [ "Camera", "classlibcamera_1_1Camera.html", "classlibcamera_1_1Camera" ],
      [ "CameraManager", "classlibcamera_1_1CameraManager.html", "classlibcamera_1_1CameraManager" ],
      [ "ColorSpace", "classlibcamera_1_1ColorSpace.html", "classlibcamera_1_1ColorSpace" ],
      [ "ControlValue", "classlibcamera_1_1ControlValue.html", "classlibcamera_1_1ControlValue" ],
      [ "ControlId", "classlibcamera_1_1ControlId.html", "classlibcamera_1_1ControlId" ],
      [ "Control", "classlibcamera_1_1Control.html", "classlibcamera_1_1Control" ],
      [ "ControlInfo", "classlibcamera_1_1ControlInfo.html", "classlibcamera_1_1ControlInfo" ],
      [ "ControlInfoMap", "classlibcamera_1_1ControlInfoMap.html", "classlibcamera_1_1ControlInfoMap" ],
      [ "ControlList", "classlibcamera_1_1ControlList.html", "classlibcamera_1_1ControlList" ],
      [ "Fence", "classlibcamera_1_1Fence.html", "classlibcamera_1_1Fence" ],
      [ "FrameMetadata", "structlibcamera_1_1FrameMetadata.html", "structlibcamera_1_1FrameMetadata" ],
      [ "FrameBuffer", "classlibcamera_1_1FrameBuffer.html", "classlibcamera_1_1FrameBuffer" ],
      [ "FrameBufferAllocator", "classlibcamera_1_1FrameBufferAllocator.html", "classlibcamera_1_1FrameBufferAllocator" ],
      [ "Point", "classlibcamera_1_1Point.html", "classlibcamera_1_1Point" ],
      [ "Size", "classlibcamera_1_1Size.html", "classlibcamera_1_1Size" ],
      [ "SizeRange", "classlibcamera_1_1SizeRange.html", "classlibcamera_1_1SizeRange" ],
      [ "Rectangle", "classlibcamera_1_1Rectangle.html", "classlibcamera_1_1Rectangle" ],
      [ "BayerFormat", "classlibcamera_1_1BayerFormat.html", "classlibcamera_1_1BayerFormat" ],
      [ "ByteStreamBuffer", "classlibcamera_1_1ByteStreamBuffer.html", "classlibcamera_1_1ByteStreamBuffer" ],
      [ "CameraControlValidator", "classlibcamera_1_1CameraControlValidator.html", "classlibcamera_1_1CameraControlValidator" ],
      [ "CameraLens", "classlibcamera_1_1CameraLens.html", "classlibcamera_1_1CameraLens" ],
      [ "CameraSensor", "classlibcamera_1_1CameraSensor.html", "classlibcamera_1_1CameraSensor" ],
      [ "CameraSensorFactoryBase", "classlibcamera_1_1CameraSensorFactoryBase.html", "classlibcamera_1_1CameraSensorFactoryBase" ],
      [ "CameraSensorFactory", "classlibcamera_1_1CameraSensorFactory.html", "classlibcamera_1_1CameraSensorFactory" ],
      [ "CameraSensorProperties", "structlibcamera_1_1CameraSensorProperties.html", "structlibcamera_1_1CameraSensorProperties" ],
      [ "ClockRecovery", "classlibcamera_1_1ClockRecovery.html", "classlibcamera_1_1ClockRecovery" ],
      [ "ControlSerializer", "classlibcamera_1_1ControlSerializer.html", "classlibcamera_1_1ControlSerializer" ],
      [ "ControlValidator", "classlibcamera_1_1ControlValidator.html", "classlibcamera_1_1ControlValidator" ],
      [ "Converter", "classlibcamera_1_1Converter.html", "classlibcamera_1_1Converter" ],
      [ "ConverterFactoryBase", "classlibcamera_1_1ConverterFactoryBase.html", "classlibcamera_1_1ConverterFactoryBase" ],
      [ "ConverterFactory", "classlibcamera_1_1ConverterFactory.html", "classlibcamera_1_1ConverterFactory" ],
      [ "ConverterDW100Module", "classlibcamera_1_1ConverterDW100Module.html", "classlibcamera_1_1ConverterDW100Module" ],
      [ "Dw100VertexMap", "classlibcamera_1_1Dw100VertexMap.html", "classlibcamera_1_1Dw100VertexMap" ],
      [ "V4L2M2MConverter", "classlibcamera_1_1V4L2M2MConverter.html", "classlibcamera_1_1V4L2M2MConverter" ],
      [ "DebugMetadata", "classlibcamera_1_1DebugMetadata.html", "classlibcamera_1_1DebugMetadata" ],
      [ "DelayedControls", "classlibcamera_1_1DelayedControls.html", "classlibcamera_1_1DelayedControls" ],
      [ "DeviceMatch", "classlibcamera_1_1DeviceMatch.html", "classlibcamera_1_1DeviceMatch" ],
      [ "DeviceEnumerator", "classlibcamera_1_1DeviceEnumerator.html", "classlibcamera_1_1DeviceEnumerator" ],
      [ "DmaBufAllocator", "classlibcamera_1_1DmaBufAllocator.html", "classlibcamera_1_1DmaBufAllocator" ],
      [ "DmaSyncer", "classlibcamera_1_1DmaSyncer.html", "classlibcamera_1_1DmaSyncer" ],
      [ "eGLImage", "classlibcamera_1_1eGLImage.html", "classlibcamera_1_1eGLImage" ],
      [ "eGL", "classlibcamera_1_1eGL.html", "classlibcamera_1_1eGL" ],
      [ "PixelFormatInfo", "classlibcamera_1_1PixelFormatInfo.html", "classlibcamera_1_1PixelFormatInfo" ],
      [ "GlobalConfiguration", "classlibcamera_1_1GlobalConfiguration.html", "classlibcamera_1_1GlobalConfiguration" ],
      [ "IPADataSerializer", "classlibcamera_1_1IPADataSerializer.html", null ],
      [ "IPAManager", "classlibcamera_1_1IPAManager.html", "classlibcamera_1_1IPAManager" ],
      [ "IPAModule", "classlibcamera_1_1IPAModule.html", "classlibcamera_1_1IPAModule" ],
      [ "IPAProxy", "classlibcamera_1_1IPAProxy.html", "classlibcamera_1_1IPAProxy" ],
      [ "IPCMessage", "classlibcamera_1_1IPCMessage.html", "classlibcamera_1_1IPCMessage" ],
      [ "IPCPipe", "classlibcamera_1_1IPCPipe.html", "classlibcamera_1_1IPCPipe" ],
      [ "IPCUnixSocket", "classlibcamera_1_1IPCUnixSocket.html", "classlibcamera_1_1IPCUnixSocket" ],
      [ "MappedBuffer", "classlibcamera_1_1MappedBuffer.html", "classlibcamera_1_1MappedBuffer" ],
      [ "MappedFrameBuffer", "classlibcamera_1_1MappedFrameBuffer.html", "classlibcamera_1_1MappedFrameBuffer" ],
      [ "Matrix", "classlibcamera_1_1Matrix.html", "classlibcamera_1_1Matrix" ],
      [ "MediaDevice", "classlibcamera_1_1MediaDevice.html", "classlibcamera_1_1MediaDevice" ],
      [ "MediaObject", "classlibcamera_1_1MediaObject.html", "classlibcamera_1_1MediaObject" ],
      [ "MediaLink", "classlibcamera_1_1MediaLink.html", "classlibcamera_1_1MediaLink" ],
      [ "MediaPad", "classlibcamera_1_1MediaPad.html", "classlibcamera_1_1MediaPad" ],
      [ "MediaEntity", "classlibcamera_1_1MediaEntity.html", "classlibcamera_1_1MediaEntity" ],
      [ "MediaPipeline", "classlibcamera_1_1MediaPipeline.html", "classlibcamera_1_1MediaPipeline" ],
      [ "PipelineHandler", "classlibcamera_1_1PipelineHandler.html", "classlibcamera_1_1PipelineHandler" ],
      [ "PipelineHandlerFactoryBase", "classlibcamera_1_1PipelineHandlerFactoryBase.html", "classlibcamera_1_1PipelineHandlerFactoryBase" ],
      [ "PipelineHandlerFactory", "classlibcamera_1_1PipelineHandlerFactory.html", "classlibcamera_1_1PipelineHandlerFactory" ],
      [ "Process", "classlibcamera_1_1Process.html", "classlibcamera_1_1Process" ],
      [ "PubKey", "classlibcamera_1_1PubKey.html", "classlibcamera_1_1PubKey" ],
      [ "SharedMem", "classlibcamera_1_1SharedMem.html", "classlibcamera_1_1SharedMem" ],
      [ "SharedMemObject", "classlibcamera_1_1SharedMemObject.html", "classlibcamera_1_1SharedMemObject" ],
      [ "Benchmark", "classlibcamera_1_1Benchmark.html", "classlibcamera_1_1Benchmark" ],
      [ "DebayerParams", "structlibcamera_1_1DebayerParams.html", "structlibcamera_1_1DebayerParams" ],
      [ "SoftwareIsp", "classlibcamera_1_1SoftwareIsp.html", "classlibcamera_1_1SoftwareIsp" ],
      [ "SwIspStats", "structlibcamera_1_1SwIspStats.html", "structlibcamera_1_1SwIspStats" ],
      [ "SwStatsCpu", "classlibcamera_1_1SwStatsCpu.html", "classlibcamera_1_1SwStatsCpu" ],
      [ "V4L2Device", "classlibcamera_1_1V4L2Device.html", "classlibcamera_1_1V4L2Device" ],
      [ "V4L2PixelFormat", "classlibcamera_1_1V4L2PixelFormat.html", "classlibcamera_1_1V4L2PixelFormat" ],
      [ "V4L2Request", "classlibcamera_1_1V4L2Request.html", "classlibcamera_1_1V4L2Request" ],
      [ "MediaBusFormatInfo", "classlibcamera_1_1MediaBusFormatInfo.html", "classlibcamera_1_1MediaBusFormatInfo" ],
      [ "V4L2SubdeviceCapability", "structlibcamera_1_1V4L2SubdeviceCapability.html", "structlibcamera_1_1V4L2SubdeviceCapability" ],
      [ "V4L2SubdeviceFormat", "structlibcamera_1_1V4L2SubdeviceFormat.html", "structlibcamera_1_1V4L2SubdeviceFormat" ],
      [ "V4L2Subdevice", "classlibcamera_1_1V4L2Subdevice.html", "classlibcamera_1_1V4L2Subdevice" ],
      [ "V4L2Capability", "structlibcamera_1_1V4L2Capability.html", "structlibcamera_1_1V4L2Capability" ],
      [ "V4L2BufferCache", "classlibcamera_1_1V4L2BufferCache.html", "classlibcamera_1_1V4L2BufferCache" ],
      [ "V4L2DeviceFormat", "classlibcamera_1_1V4L2DeviceFormat.html", "classlibcamera_1_1V4L2DeviceFormat" ],
      [ "V4L2VideoDevice", "classlibcamera_1_1V4L2VideoDevice.html", "classlibcamera_1_1V4L2VideoDevice" ],
      [ "V4L2M2MDevice", "classlibcamera_1_1V4L2M2MDevice.html", "classlibcamera_1_1V4L2M2MDevice" ],
      [ "Vector", "classlibcamera_1_1Vector.html", "classlibcamera_1_1Vector" ],
      [ "YamlObject", "classlibcamera_1_1YamlObject.html", "classlibcamera_1_1YamlObject" ],
      [ "YamlParser", "classlibcamera_1_1YamlParser.html", null ],
      [ "ipa_controls_header", "structlibcamera_1_1ipa__controls__header.html", "structlibcamera_1_1ipa__controls__header" ],
      [ "ipa_control_value_entry", "structlibcamera_1_1ipa__control__value__entry.html", "structlibcamera_1_1ipa__control__value__entry" ],
      [ "ipa_control_list_entry", "structlibcamera_1_1ipa__control__list__entry.html", "structlibcamera_1_1ipa__control__list__entry" ],
      [ "ipa_control_info_entry", "structlibcamera_1_1ipa__control__info__entry.html", "structlibcamera_1_1ipa__control__info__entry" ],
      [ "IPAInterface", "classlibcamera_1_1IPAInterface.html", null ],
      [ "IPAModuleInfo", "structlibcamera_1_1IPAModuleInfo.html", "structlibcamera_1_1IPAModuleInfo" ],
      [ "PixelFormat", "classlibcamera_1_1PixelFormat.html", "classlibcamera_1_1PixelFormat" ],
      [ "Request", "classlibcamera_1_1Request.html", "classlibcamera_1_1Request" ],
      [ "StreamFormats", "classlibcamera_1_1StreamFormats.html", "classlibcamera_1_1StreamFormats" ],
      [ "StreamConfiguration", "structlibcamera_1_1StreamConfiguration.html", "structlibcamera_1_1StreamConfiguration" ],
      [ "Stream", "classlibcamera_1_1Stream.html", "classlibcamera_1_1Stream" ],
      [ "LogOutput", "classlibcamera_1_1LogOutput.html", "classlibcamera_1_1LogOutput" ],
      [ "Logger", "classlibcamera_1_1Logger.html", "classlibcamera_1_1Logger" ],
      [ "MessageQueue", "classlibcamera_1_1MessageQueue.html", "classlibcamera_1_1MessageQueue" ],
      [ "ThreadData", "classlibcamera_1_1ThreadData.html", "classlibcamera_1_1ThreadData" ],
      [ "ThreadMain", "classlibcamera_1_1ThreadMain.html", "classlibcamera_1_1ThreadMain" ],
      [ "Debayer", "classlibcamera_1_1Debayer.html", "classlibcamera_1_1Debayer" ],
      [ "DebayerCpu", "classlibcamera_1_1DebayerCpu.html", "classlibcamera_1_1DebayerCpu" ],
      [ "DebayerEGL", "classlibcamera_1_1DebayerEGL.html", "classlibcamera_1_1DebayerEGL" ],
      [ "IPACameraSensorInfo", "structlibcamera_1_1IPACameraSensorInfo.html", "structlibcamera_1_1IPACameraSensorInfo" ],
      [ "IPABuffer", "structlibcamera_1_1IPABuffer.html", "structlibcamera_1_1IPABuffer" ],
      [ "IPASettings", "structlibcamera_1_1IPASettings.html", "structlibcamera_1_1IPASettings" ],
      [ "IPAStream", "structlibcamera_1_1IPAStream.html", "structlibcamera_1_1IPAStream" ]
    ] ]
];